<?php

namespace Inventory\Pricelist\Policies;

use Litepie\User\Contracts\UserPolicy;
use Inventory\Pricelist\Models\Pricelist;

class PricelistPolicy
{

    /**
     * Determine if the given user can view the pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pricelist $pricelist)
    {
        if ($user->canDo('pricelist.pricelist.view') && $user->isAdmin()) {
            return true;
        }

        return $pricelist->user_id == user_id() && $pricelist->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pricelist.pricelist.create');
    }

    /**
     * Determine if the given user can update the given pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pricelist $pricelist)
    {
        if ($user->canDo('pricelist.pricelist.edit') && $user->isAdmin()) {
            return true;
        }

        return $pricelist->user_id == user_id() && $pricelist->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pricelist $pricelist)
    {
        return $pricelist->user_id == user_id() && $pricelist->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pricelist $pricelist)
    {
        if ($user->canDo('pricelist.pricelist.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pricelist.
     *
     * @param UserPolicy $user
     * @param Pricelist $pricelist
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pricelist $pricelist)
    {
        if ($user->canDo('pricelist.pricelist.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
